<?php

namespace HCM\AVL\Services;

use Doctrine\ORM\EntityManager;
use Avaliacao\Entities\Criterioresult;
use Avaliacao\Entities\Faixacritresult;
use HCM\Util\HCMParameters;
use HCM\Util\Messages;
use HCM\Util\Repositories;
use HCM\AVL\Repository\CriterioResultadoRepository;

class CriterioResultadoService {
    
    protected $entityManager;
    protected $hcmParameters;
    protected $criterioResultadoRepository;
    
    public function __construct(EntityManager $entityManager, HCMParameters $hcmParameters,\HCM\AVL\Repository\CriterioResultadoRepository $criterioResultadoRepository) {
        $this->entityManager = $entityManager;
        $this->hcmParameters = $hcmParameters;
        $this->criterioResultadoRepository = $criterioResultadoRepository;
    }
    
    public function checkCriterioResultado($dataset) {
        $nrCriterioResul = $dataset["NRCRITERIORESUL"];
        $faixaCriterio = $this->criterioResultadoRepository->getFaixaCritResult($nrCriterioResul, $dataset['NRORG']);
        if (isset($faixaCriterio[0])) {
            return $faixaCriterio;
        }
        else {
            return false;
        }
    }
    
    public function deleteFaixasECriterio($dataset){
        try {
            $this->entityManager->beginTransaction();
            
            $this->deleteFaixaCritResult($dataset["FAIXAS"]);
            $this->deleteCriterio($dataset);
            
            $this->entityManager->flush();
            $this->entityManager->commit();
            
        } catch(\Exception $e){
            $this->entityManager->rollback();
            if(strpos($e->getMessage(), "ORA-02292") !== false){
                //compara se a mensagem do erro é de violação da restrição de integridade da tebela, se for o critério está cadastrado em outros processos
                throw new \Exception(Messages::HCM03000_AVL_CRITERIORESUL_EXISTS_AVALIACAO_QUESTIONARIO_ERROR, 5);
            } else {
                throw $e;
            }
        }
    }
    
    public function deleteCriterioResultado($dataset){
        try{
            $this->entityManager->beginTransaction();
            $this->deleteCriterio($dataset);
            $this->entityManager->flush();
            $this->entityManager->commit();
        } catch(\Exception $e){
            $this->entityManager->rollback();
            if(strpos($e->getMessage(), "ORA-02292") !== false){
                //compara se a mensagem do erro é de violação da restrição de integridade da tebela, se for o critério está cadastrado em outros processos
                throw new \Exception(Messages::HCM03000_AVL_CRITERIORESUL_EXISTS_AVALIACAO_QUESTIONARIO_ERROR, 5);
            } else {
                throw $e;
            }
        }
    }
    
    public function deleteCriterio($dataset) {
        $criterioResult = $this->entityManager->getRepository(Repositories::CRITERIORESULT)->findOneBy(array('nrorg' => $dataset["NRORG"], 'nrcriterioresul' => $dataset["NRCRITERIORESUL"]));
        $this->entityManager->remove($criterioResult);
    }

    
    public function deleteFaixaCritResult($faixas){
        foreach($faixas as $faixa){
            $faixaCritResult = $this->entityManager->getRepository(Repositories::FAIXACRITRESULT)->findOneBy(array('nrorg' => $faixa["NRORG"], 'nrfaixacriresul' => $faixa["NRFAIXACRIRESUL"]));
            $this->entityManager->remove($faixaCritResult);
        }
    }
}