<?php

namespace HCM\Geral\Controllers;

use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use HCM\Util\HCMParameters;
use Doctrine\ORM\EntityManager;
use HCM\Util\Repositories;
use HCM\Util\DateUtil;

class IntegracaoDigitalCertisignController extends Crud {

    protected $dataSourceName            = 'getGpe_inteletrdigit';
    protected $setDataSourceName         = 'gpe_inteletrdigit';
    
    protected $parameterBagColumns = array('P_NRORG', 'P_NRORG_PADRAO', 'P_DTMESCOMPETENC');
    public function __construct (Manager $dataSourceManager, ParameterBag $parameterBag, HCMParameters $hcmParameters, EntityManager $entityManager){
        $this->parameterBag       = $parameterBag;
        $this->hcmParameters      = $hcmParameters;
        $this->entityManager      = $entityManager;
        $this->pessoa             = Repositories::GPE_PESSOA;
        parent::__construct($dataSourceManager);
    }

    public function getAssinaturaEletronica(DTO\Request\Filter $request, DTO\Response $response) {
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->dataSourceName);
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData);
        $response->addDataSet($dataSet);
    }
    
    public function setAssinaturaEletronica(DTO\Request\DataSet $request, DTO\Response $response) {
        $this->dataSourceName = $this->setDataSourceName;
        try {
            $row            = $request->getDataSet()->getRows()[0];
            $nrorg          = $this->hcmParameters->getNrorgTrabalho();
            $dtmescompetenc = $this->hcmParameters->getDtCompetencia();
            $nrPessoa       = $row['NRPESSOA'];
            if ($row["__is_new"]){ 
                $row['NRINTELETRDIGIT'] = \HCM\Util\NovoCodigo::geraCodigo($nrorg, 'GPE_INTELETRDIGIT', 1, 12, true);
            }
            parent::save($request, $response);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    
    public function deleteAssinaturaEletronica(DTO\Request\DataSet $request, DTO\Response $response){
        try{
            parent::delete($request, $response);
        } catch(\Exception $e){
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }    
    }

    protected function processConditionValue($condition) {
        return $condition['value'];
    }
    protected function populateParameterBag(FilterCriteria $filterCriteria) {

        $conditions = array();
        foreach ($filterCriteria->getConditions() as $condition) {
            $columnName = $condition['columnName'];
            if (in_array($columnName, $this->parameterBagColumns)) {
                $this->parameterBag->set($columnName, $this->processConditionValue($condition));
            } else {
                $conditions[] = $condition;
            }
        }
        $newFilterCriteria = new FilterCriteria(
            $filterCriteria->getDataSourceName(),
            $conditions,
            $filterCriteria->getPage(),
            $filterCriteria->getPageSize()
        );
        return $newFilterCriteria;
    }
} 